# ciopath
Object-oriented platform-transparent path manipulations
 
## Install

```bash
pip install --upgrade ciopath
```

## Usage

## Test

```
python -m unittest discover -v -s ./tests  -p 'test_*.py'
```

## Contributing

Pull requests welcome. 

## License
[MIT](LICENSE)
